<clientConfig version="1.1">
  <emailProvider id="broba.cc">
    <domain>garnet.broba.cc</domain>
    <domain>amethyst.broba.cc</domain>
    <domain>coral.broba.ccv</domain>
    <domain>diamond.broba.cc</domain>
    <displayName>ぷらら</displayName>
    <displayShortName>ぷらら</displayShortName>
    <incomingServer type="pop3">
      <hostname>mail.broba.cc</hostname>
      <port>110</port>
      <socketType>plain</socketType>
      <username>%EMAILADDRESS%</username>
      <authentication>password-cleartext</authentication>
    </incomingServer>
    <outgoingServer type="smtp">
      <hostname>mail.broba.cc</hostname>
      <port>587</port>
      <socketType>plain</socketType>
      <username>%EMAILADDRESS%</username>
      <authentication>password-cleartext</authentication>
    </outgoingServer>
  </emailProvider>
</clientConfig>
