<clientConfig version="1.1">
  <emailProvider id="o2.pl">
    <domain>o2.pl</domain>
    <domain>go2.pl</domain>
    <domain>tlen.pl</domain>
    <domain>prokonto.pl</domain>
    <displayName>o2 Poczta</displayName>
    <displayShortName>o2</displayShortName>
    <incomingServer type="imap">
      <hostname>poczta.o2.pl</hostname>
      <port>993</port>
      <socketType>SSL</socketType>
      <authentication>password-cleartext</authentication>
      <username>%EMAILLOCALPART%</username>
    </incomingServer>
    <incomingServer type="pop3">
      <hostname>poczta.o2.pl</hostname>
      <port>995</port>
      <socketType>SSL</socketType>
      <authentication>password-cleartext</authentication>
      <username>%EMAILLOCALPART%</username>
    </incomingServer>
    <outgoingServer type="smtp">
      <hostname>poczta.o2.pl</hostname>
      <port>465</port>
      <socketType>SSL</socketType>
      <authentication>password-cleartext</authentication>
      <username>%EMAILLOCALPART%</username>
      <restriction>client-IP-address</restriction>
    </outgoingServer>
    <outgoingServer type="smtp">
      <hostname>poczta.o2.pl</hostname>
      <port>587</port>
      <socketType>STARTTLS</socketType>
      <authentication>password-cleartext</authentication>
      <username>%EMAILLOCALPART%</username>
      <restriction>client-IP-address</restriction>
    </outgoingServer>
    <documentation url="https://pomoc.o2.pl/jak-skonfigurowac-program-pocztowy">
      <descr lang="pl">Jak skonfigurować program pocztowy</descr>
    </documentation>
    <documentation url="https://pomoc.o2.pl/aktywacja-dostepu-dla-programow-pocztowych">
      <descr lang="pl">Aktywacja dostępu dla programów pocztowych</descr>
    </documentation>
  </emailProvider>
</clientConfig>
