//
// The Phoenix shall be followed by a Dove: one of great strength and great beauty, to help carry out its conquest.

pref("general.config.sandbox_enabled", true, locked);

pref("general.config.filename", "dove.cfg", locked);
pref("general.config.obscure_value", 0, locked);
pref("general.config.vendor", "dove", locked);

pref("mail.dove.applied.prefs", true, locked);
